pub struct MessageEnvelope { /* private fields */ }Expand description
Metadata carried alongside every dispatch.
The envelope exposes the message type name and identifiers without
requiring the middleware to know the concrete Command or Query type.
Implementations
Sourceimpl MessageEnvelope
impl MessageEnvelope
Sourcepub fn for_command<C: Command>(
message_id: MessageId,
correlation_id: CorrelationId,
) -> Self
pub fn for_command<C: Command>( message_id: MessageId, correlation_id: CorrelationId, ) -> Self
Builds an envelope for a Command dispatch.
Sourcepub fn for_query<Q: Query>(
message_id: MessageId,
correlation_id: CorrelationId,
) -> Self
pub fn for_query<Q: Query>( message_id: MessageId, correlation_id: CorrelationId, ) -> Self
Builds an envelope for a Query dispatch.
Sourcepub fn type_name(&self) -> &'static str
pub fn type_name(&self) -> &'static str
The fully-qualified type name of the dispatched message.
Sourcepub fn message_id(&self) -> MessageId
pub fn message_id(&self) -> MessageId
The unique identifier of this dispatch.
Sourcepub fn correlation_id(&self) -> CorrelationId
pub fn correlation_id(&self) -> CorrelationId
The correlation identifier linking this dispatch to its causal chain.